@@ -3,11 +3,10 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from six import string_types as STRING_TYPES
-
-from .util import StatusTag
+from .util import StatusTag, color_map
 
 DEFAULT_DEPRECATED_TAG = '[Deprecated]'
+_config_key = 'deprecation'
 
 
 def resolve_deprecate_info(cli_ctx, name):
@@ -40,7 +39,7 @@ class Deprecated(StatusTag):
         deprecate_info = kwargs.get('deprecate_info', None)
         if isinstance(deprecate_info, Deprecated):
             deprecate_info.object_type = object_type
-        elif isinstance(deprecate_info, STRING_TYPES):
+        elif isinstance(deprecate_info, str):
             deprecate_info = Deprecated(cli_ctx, redirect=deprecate_info, object_type=object_type)
         kwargs['deprecate_info'] = deprecate_info
         return deprecate_info
@@ -84,12 +83,13 @@ class Deprecated(StatusTag):
         self.redirect = redirect
         self.hide = hide
         self.expiration = expiration
+        self._cli_version = cli_ctx.get_cli_version()
 
-        super(Deprecated, self).__init__(
+        super().__init__(
             cli_ctx=cli_ctx,
             object_type=object_type,
             target=target,
-            color='yellow',
+            color=color_map[_config_key],
             tag_func=tag_func or (lambda _: DEFAULT_DEPRECATED_TAG),
             message_func=message_func or _default_get_message
         )
@@ -103,17 +103,15 @@ class Deprecated(StatusTag):
 
     def expired(self):
         if self.expiration:
-            cli_version = self.cli_ctx.get_cli_version()
-            return self._version_less_than_or_equal_to(self.expiration, cli_version)
+            return self._version_less_than_or_equal_to(self.expiration, self._cli_version)
         return False
 
     def hidden(self):
         hidden = False
         if isinstance(self.hide, bool):
             hidden = self.hide
-        elif isinstance(self.hide, STRING_TYPES):
-            cli_version = self.cli_ctx.get_cli_version()
-            hidden = self._version_less_than_or_equal_to(self.hide, cli_version)
+        elif isinstance(self.hide, str):
+            hidden = self._version_less_than_or_equal_to(self.hide, self._cli_version)
         return hidden
 
     def show_in_help(self):
@@ -139,4 +137,4 @@ class ImplicitDeprecated(Deprecated):
             'tag_func': lambda _: '',
             'message_func': get_implicit_deprecation_message
         })
-        super(ImplicitDeprecated, self).__init__(**kwargs)
+        super().__init__(**kwargs)
