@@ -9,15 +9,40 @@ import re
 from datetime import date, time, datetime, timedelta
 from enum import Enum
 
+NO_COLOR_VARIABLE_NAME = 'KNACK_NO_COLOR'
+
+# Override these values to customize the status message.
+# The message should contain a placeholder indicating the subject (like 'This command group', 'Command group xxx').
+# (A dict is used to avoid the "from A import B" pitfall that creates a copy of the imported B.)
+status_tag_messages = {
+    'preview': "{} is in preview. It may be changed/removed in a future release.",
+    'experimental': "{} is experimental and under development."
+}
+
+# https://docs.microsoft.com/en-us/windows/console/console-virtual-terminal-sequences
+color_map = {
+    'reset': '\x1b[0m',  # Default
+    'preview': '\x1b[36m',  # Foreground Cyan
+    'experimental': '\x1b[36m',  # Foreground Cyan
+    'deprecation': '\x1b[33m',   # Foreground Yellow
+    'critical': '\x1b[41m',  # Background Red
+    'error': '\x1b[91m',  # Bright Foreground Red
+    'warning': '\x1b[33m',  # Foreground Yellow
+    'info': '\x1b[32m',  # Foreground Green
+    'debug': '\x1b[36m',  # Foreground Cyan
+}
+
 
 class CommandResultItem(object):  # pylint: disable=too-few-public-methods
     def __init__(self, result, table_transformer=None, is_query_active=False,
-                 exit_code=0, error=None):
+                 exit_code=0, error=None, raw_result=None):
         self.result = result
         self.error = error
         self.exit_code = exit_code
         self.table_transformer = table_transformer
         self.is_query_active = is_query_active
+        # The result before applying query
+        self.raw_result = raw_result
 
 
 class CLIError(Exception):
@@ -32,54 +57,35 @@ class CtxTypeError(TypeError):
 
     def __init__(self, obj):
         from .cli import CLI
-        super(CtxTypeError, self).__init__('expected instance of {} got {}'.format(CLI.__name__,
-                                                                                   obj.__class__.__name__))
+        super().__init__('expected instance of {} got {}'.format(CLI.__name__, obj.__class__.__name__))
 
 
 class ColorizedString(object):
 
     def __init__(self, message, color):
-        import colorama
         self._message = message
-        self._color = getattr(colorama.Fore, color.upper(), None)
+        self._color = color
 
     def __len__(self):
         return len(self._message)
 
     def __str__(self):
-        import colorama
         if not self._color:
             return self._message
-        return self._color + self._message + colorama.Fore.RESET
+        return self._color + self._message + color_map['reset']
 
 
 class StatusTag(object):
 
     # pylint: disable=unused-argument
     def __init__(self, cli_ctx, object_type, target, tag_func, message_func, color, **kwargs):
-        self.cli_ctx = cli_ctx
         self.object_type = object_type
         self.target = target
         self._color = color
+        self._enable_color = cli_ctx.enable_color
         self._get_tag = tag_func
         self._get_message = message_func
 
-    def __deepcopy__(self, memo):
-        import copy
-
-        cls = self.__class__
-        result = cls.__new__(cls)
-        memo[id(self)] = result
-        for k, v in self.__dict__.items():
-            try:
-                setattr(result, k, copy.deepcopy(v, memo))
-            except TypeError:
-                if k == 'cli_ctx':
-                    setattr(result, k, self.cli_ctx)
-                else:
-                    raise
-        return result
-
     # pylint: disable=no-self-use
     def hidden(self):
         return False
@@ -90,12 +96,13 @@ class StatusTag(object):
     @property
     def tag(self):
         """ Returns a tag object. """
-        return ColorizedString(self._get_tag(self), self._color)
+        return ColorizedString(self._get_tag(self), self._color) if self._enable_color else self._get_tag(self)
 
     @property
     def message(self):
         """ Returns a tuple with the formatted message string and the message length. """
-        return ColorizedString(self._get_message(self), self._color)
+        return ColorizedString(self._get_message(self), self._color) if self._enable_color \
+            else "WARNING: " + self._get_message(self)
 
 
 def ensure_dir(d):
@@ -148,3 +155,24 @@ def todict(obj, post_processor=None):  # pylint: disable=too-many-return-stateme
                   if not callable(v) and not k.startswith('_')}
         return post_processor(obj, result) if post_processor else result
     return obj
+
+
+def is_modern_terminal():
+    """Detect whether the current terminal is a modern terminal that supports Unicode and
+    Console Virtual Terminal Sequences.
+
+    Currently, these terminals can be detected:
+      - VS Code terminal
+      - PyCharm
+      - Windows Terminal
+    """
+    # VS Code: https://github.com/microsoft/vscode/pull/30346
+    if os.environ.get('TERM_PROGRAM', '').lower() == 'vscode':
+        return True
+    # PyCharm: https://youtrack.jetbrains.com/issue/PY-4853
+    if 'PYCHARM_HOSTED' in os.environ:
+        return True
+    # Windows Terminal: https://github.com/microsoft/terminal/issues/1040
+    if 'WT_SESSION' in os.environ:
+        return True
+    return False
